summaryrefslogtreecommitdiffstats
path: root/kio/kio/kservicegroupfactory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kio/kservicegroupfactory.cpp')
-rw-r--r--kio/kio/kservicegroupfactory.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kio/kio/kservicegroupfactory.cpp b/kio/kio/kservicegroupfactory.cpp
index 9a2ae33f2..9bca4dc63 100644
--- a/kio/kio/kservicegroupfactory.cpp
+++ b/kio/kio/kservicegroupfactory.cpp
@@ -36,7 +36,7 @@ KServiceGroupFactory::KServiceGroupFactory()
if (m_str)
{
// Read Header
- TQ_INT32 i;
+ Q_INT32 i;
(*m_str) >> i;
m_baseGroupDictOffset = i;
@@ -66,12 +66,12 @@ KServiceGroupFactory * KServiceGroupFactory::self()
return _self;
}
-KServiceGroup * KServiceGroupFactory::tqfindGroupByDesktopPath(const TQString &_name, bool deep)
+KServiceGroup * KServiceGroupFactory::findGroupByDesktopPath(const TQString &_name, bool deep)
{
if (!m_sycocaDict) return 0; // Error!
// Warning : this assumes we're NOT building a database
// But since tqfindServiceByName isn't called in that case...
// [ see KServiceTypeFactory for how to do it if needed ]
int offset = m_sycocaDict->find_string( _name );
@@ -89,12 +89,12 @@ KServiceGroup * KServiceGroupFactory::tqfindGroupByDesktopPath(const TQString &_
return newGroup;
}
-KServiceGroup * KServiceGroupFactory::tqfindBaseGroup(const TQString &_baseGroupName, bool deep)
+KServiceGroup * KServiceGroupFactory::findBaseGroup(const TQString &_baseGroupName, bool deep)
{
if (!m_baseGroupDict) return 0; // Error!
// Warning : this assumes we're NOT building a database
// But since tqfindServiceByName isn't called in that case...
// [ see KServiceTypeFactory for how to do it if needed ]
int offset = m_baseGroupDict->find_string( _baseGroupName );
@@ -66,12 +66,12 @@ KServiceGroupFactory * KServiceGroupFactory::self()
if (!m_sycocaDict) return 0; // Error!
// Warning : this assumes we're NOT building a database
- // But since tqfindServiceByName isn't called in that case...
+ // But since findServiceByName isn't called in that case...
// [ see KServiceTypeFactory for how to do it if needed ]
int offset = m_sycocaDict->find_string( _name );
@@ -89,12 +89,12 @@ KServiceGroup * KServiceGroupFactory::tqfindGroupByDesktopPath(const TQString &_
if (!m_baseGroupDict) return 0; // Error!
// Warning : this assumes we're NOT building a database
- // But since tqfindServiceByName isn't called in that case...
+ // But since findServiceByName isn't called in that case...
// [ see KServiceTypeFactory for how to do it if needed ]
int offset = m_baseGroupDict->find_string( _baseGroupName );